@@ -12,6 +12,9 @@ static char *i_format_list[]={
 #endif
 #ifdef HAVE_LIBT1
   "t1",
+#endif
+#ifdef HAVE_LIBTT
+  "tt",
 #endif
   "raw",
   "ppm",
